@@ -11,7 +11,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: availability.c 7085 2012-07-16 11:08:37Z storner $";
+static char rcsid[] = "$Id: availability.c 7678 2015-10-01 14:42:42Z jccleaver $";
 
 #include <limits.h>
 #include <stdio.h>
@@ -401,7 +401,7 @@ int parse_historyfile(FILE *fd, reportinfo_t *repinfo, char *hostname, char *ser
 	/* Sanity check */
 	if (totime > getcurrenttime(NULL)) totime = getcurrenttime(NULL);
 
-	/* If for_history and fromtime is 0, dont do any seeking */
+	/* If for_history and fromtime is 0, don't do any seeking */
 	if (!for_history || (fromtime > 0)) {
 		fileerrors = scan_historyfile(fd, fromtime, totime, 
 				      l, sizeof(l), &starttime, &duration, colstr);
