@@ -11,7 +11,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: environ.c 7713 2015-11-02 14:56:33Z jccleaver $";
+static char rcsid[] = "$Id: environ.c 7713M 2016-02-05 20:50:18Z (local) $";
 
 #include <ctype.h>
 #include <string.h>
@@ -89,6 +89,7 @@ const static struct {
 	{ "XYMONHOSTHISTLOG", "TRUE" },
 	{ "SAVESTATUSLOG", "TRUE" },
 	{ "CLIENTLOGS", "$XYMONVAR/hostdata" },
+	{ "DU", "du -k" },
 	{ "MAILC", "mail" },
 	{ "MAIL", "$MAILC -s" },
 	{ "SVCCODES", "disk:100,cpu:200,procs:300,svcs:350,msgs:400,conn:500,http:600,dns:800,smtp:725,telnet:723,ftp:721,pop:810,pop3:810,pop-3:810,ssh:722,imap:843,ssh1:722,ssh2:722,imap2:843,imap3:843,imap4:843,pop2:809,pop-2:809,nntp:819,test:901" },
@@ -140,6 +141,7 @@ const static struct {
 	{ "XYMONHISTEXT", "" },
 	{ "TASKSLEEP", "300" },
 	{ "XYMONPAGECOLREPEAT", "0" },
+	{ "ALLOWALLCONFIGFILES", "" },
 	{ "XYMONHTACCESS", "" },
 	{ "XYMONPAGEHTACCESS", "" },
 	{ "XYMONSUBPAGEHTACCESS", "" },
