@@ -11,7 +11,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: headfoot.c 7678 2015-10-01 14:42:42Z jccleaver $";
+static char rcsid[] = "$Id: headfoot.c 7678M 2016-02-05 20:50:18Z (local) $";
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -1645,7 +1645,7 @@ void showform(FILE *output, char *headertemplate, char *formtemplate, int color,
 		close(formfile);
 
 		if (headertemplate) headfoot(output, headertemplate, (hostenv_pagepath ? hostenv_pagepath : ""), "header", color);
-		if (pretext) fprintf(output, "%s", pretext);
+		if (pretext) fprintf(output, "<center><strong><big>%s</big></strong></center>\n", pretext);
 		output_parsed(output, inbuf, color, seltime);
 		if (posttext) fprintf(output, "%s", posttext);
 		if (headertemplate) headfoot(output, headertemplate, (hostenv_pagepath ? hostenv_pagepath : ""), "footer", color);
