@@ -10,7 +10,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: trimhistory.c 7085 2012-07-16 11:08:37Z storner $";
+static char rcsid[] = "$Id: trimhistory.c 7678 2015-10-01 14:42:42Z jccleaver $";
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -492,7 +492,7 @@ int main(int argc, char *argv[])
 	/* Process statuslogs also ? */
 	if (!droplogs) return 0;
 
-	flhead = NULL;  /* Dirty - we should clean it up properly - but I dont care */
+	flhead = NULL;  /* Dirty - we should clean it up properly - but I don't care */
 	totalitems = 0;
 	if (chdir(xgetenv("XYMONHISTLOGS")) == -1) {
 		errprintf("Cannot cd to historical statuslogs directory: %s\n", strerror(errno));
